itchecker
========================

itchecker is a tool to check Excel, Word and Access files.


Usage
-----

Excel testing::

 itchecker  --checker excel --works-folder ./works --test-file ./tests_excel.xlsx --correct-file ./author.xlsx --output-folder ./output_excel

----

Access testing::

 itchecker  --checker access --works-folder ./works --test-file ./tests_access.xlsx --correct-file ./author.accdb --output-folder ./output_access

----

Word testing::

 itchecker  --checker word --works-folder ./works --test-file ./tests_word.xlsx --correct-file ./author.docx --output-folder ./output_word

